BaseProductionController class

Inheritance
Implemented types
Implementers

Constructors

BaseProductionController(dynamic dataCertificate)

Properties

appController AppController?
getter/setter pair
callBackRenderView CallbackData?
getter/setter pair
context BuildContext?
getter/setter pairinherited
currentPage int
getter/setter pair
dataCertificate ↔ dynamic
getter/setter pair
formKD Map<String, dynamic>?
getter/setter pair
formKdLoaded bool
getter/setter pair
formKenhNdCdLkeLoaded bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isEditFormOverView bool
getter/setter pair
isOverViewPage ↔ RxBool
getter/setter pair
isPrepareNextPage ↔ RxBool
getter/setter pair
isSendPushCore bool
getter/setter pair
isSendPushCoreSuccess ↔ RxBool
getter/setter pair
isShowKey ↔ RxBool
getter/setter pairinherited
isShowLoading bool
getter/setter pairinherited
kenhKTView String
getter/setter pair
lhNV String
getter/setter pair
listeners int
no setterinherited
lsControlForOverViewPage List<BoxOverviewPage>
getter/setter pair
lsPages List<PageControl>
getter/setter pair
lsRow List<Widget>
getter/setter pair
maNV String
getter/setter pair
maxPageShow int?
getter/setter pair
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
pageOverview PageOverview
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeFrom String
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addInputParamsDefault(List<Control> controls) → void
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
addObjectToPage(List<Control> controls) → void
callApiApproval(CertificateObj certificate, CallbackData callback) → void
inherited
callApiLayKenhNdCdLke(String nv, String lhNv, CallbackData? callback) Future<void>
callFormKhoiDong() → dynamic
callKenhNdCdLke({String? lhNv}) → dynamic
checkHideAndShowFromKenhNdCd(dynamic lsKenhNdCdLke) → void
checkSetVisibleNhom() → void
closeLoading() → dynamic
inherited
didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
inherited
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
inherited
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
disableInputWithUserNormal() → void
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
filterWidget(List<List<Control>> listControls, {String idRemove = ""}) List<List<Control>>
findAndUpdateControlById(String id, {bool update = false, Control? controlNew}) Control?
findControlInputForm(String id, {List<Widget> lsRows = const []}) FormObject
findControlInputFormAllPage(String id) Control
getDataFromListControl(List<List<Control>> listControls) Map<String, dynamic>
getDataInForm({bool isAllForm = false, List<List<Control>>? lsRows}) Map<String, dynamic>
getWidgetRender() List<Widget>
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
initControlForOverViewPage() List<BoxOverviewPage>
initWidgetForm() → void
jumpleOverviewPage() → void
jumpleToIndexPage(int index) → void
lowerCaseKeyData(List ls) → dynamic
nextPage() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
ocrCMT(String imageUrl, String? title) Future
ocrDangKiem(String imageUrl, String? title, TypeOCR type) Future
onChangeHDKhac(Control? obj) → void
onChanges(FormObject obj) → void
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onEditingComplete(FormObject obj) Future<void>
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
parseDataForInitForm(dynamic data) → dynamic
parseKenhNdCd(dynamic field, Control control) → dynamic
popToScreen({required String screen}) → void
previousPage() → void
printDebug(dynamic data) → void
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
refreshValueSelectedDropDownSearch({List<Widget> lsRows = const [], String ma = "", dynamic isForceReFresh = false}) → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
renderRow(List<List<Control>>? ls) List<Widget>
renderView(Control control, dynamic index, dynamic isLastRow, dynamic isFirstRow) Widget?
reRender() → void
resetDropDownSelected(String id, {bool isForceReFresh = false}) → dynamic
setDataForDropDown(String idWidget, List data, {List<Widget> lsRows = const []}) → void
setDataForDropDownALLNew(dynamic formKD, {String id = "", dynamic listData}) → void
setDataForDropDownNew(FormKD formKD, {List<Widget> lsRows = const []}) → void
setTitleForFormByIdWidget(String idWidget, dynamic data, {List<Widget> lsRows = const []}) → void
setValueBuyControl(String idWidget, dynamic data) → void
setValueByKey(dynamic chiTietDon, String key, {dynamic value = ""}) → void
setValueByKeyAllNew(dynamic chiTietDon, {dynamic value = "", List<Widget> lsRows = const []}) → void
setValueByKeyNew(dynamic chiTietDon, {dynamic value = "", List<Widget> lsRows = const []}) → void
setValueForFormByIdWidget(String idWidget, dynamic data, {List<Widget> lsRows = const []}) → void
setValueSelectedForDropDown(String key, {int index = 0, dynamic lsControl, bool isSetUpadteValue = false}) → void
setValueSelectedForDropDownALLNew() → void
setValueSelectedForDropDownNew({bool isSetUpadteValue = false, List<Widget> lsRows = const []}) → void
setVisible(List<List<Control>> listControls, bool visible) → void
setVisibleByGroupDN(bool visible) → void
setVisibleById(String id, bool visible, {dynamic data}) → void
showAlertDialogMessage({String? title, String content = "", double maxHeight = 150, VoidCallback? onDoneClick, VoidCallback? onCancelClick, String? titleButtonCancel, String? titleButtonDone}) → dynamic
inherited
showLoading({int timeout = 30}) → dynamic
inherited
showPicker({CallbackData? callback, CameraType type = CameraType.full, bool resizeImage = true}) → void
inherited
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateControlForInputForm(Control newControl) → void
updateDropwDonw({required DropdownSearchProduction child, bool isForceReFresh = false}) → dynamic
upperCaseKeyData(List ls) → dynamic
validateDropDownSearch() bool
validateForm() bool
visibleInfoInHdKhac(Control? obj) → void
visibleInputOfUser({String product = ""}) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited