BaseState<Screen extends BaseScreen> class abstract

Inheritance
Implementers

Constructors

BaseState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isShowLoading bool
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → Screen
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
closeKeyborad() → dynamic
closeLoading() → dynamic
createBottomBar() Widget?
createFloatingButton() Widget?
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant Screen oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getDefaultFloatingButton({required VoidCallback onPress}) Widget
getFloatingButton({required Color color, required IconData iconData, required VoidCallback onPress}) Widget
headerView({required String title, Color backgroundColor = white, Color textColor = neutral_500, List<Widget>? actions, Widget? leading, TabBar? tabBar, double elevation = 0.5, bool isShowBack = true}) AppBar
heightBottomSafa() double
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
popToScreen({required String screen}) → void
printDebug(dynamic data) → void
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showAlertDialogAction(VoidCallback onPressYes, BuildContext context, String message, String content, String nameAction) → dynamic
showAlertDialogMessage({String? title, String content = "", double maxHeight = 150, String textCancel = "Huỷ", String textDone = "Đồng ý", VoidCallback? onDoneClick, VoidCallback? onCancelClick}) → dynamic
showDropDown({String title = "", double heightView = 300, List<OptionItem> items = const [], bool isSearch = false, CallbackData? callback, String hindText = "", Widget? childPopup, OptionItem? initItem}) → dynamic
showLoading({int timeout = 30}) → dynamic
showMessage(String content, ScaffoldState scaffoldState) → void
showPicker({CallbackData? callback, CameraType type = CameraType.full, bool isPopView = true}) → void
showPopupConfirm({String title = "", String content = "", String textButton = "", required String screen}) → dynamic
showProcessingFeatureMessage(ScaffoldState scaffoldState) → void
tabBars({List<Tab>? tabs, bool isScrollable = false, TabController? controller, EdgeInsetsGeometry labelPadding = const EdgeInsets.symmetric(horizontal: 0), EdgeInsetsGeometry indicatorPadding = const EdgeInsets.symmetric(horizontal: 0), CallbackData? callback}) TabBar
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited