HighlightIndex class

Constructors

HighlightIndex(int idxFrom, int length)

Properties

hashCode int
The hash code for this object.
no setterinherited
idxFrom int
final
idxTo int
no setter
length int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String content, String highlight) List<HighlightIndex>