BasicState<Screen extends BaseScreen> mixin

Superclass constraints

Properties

colorSafeArea Color
no setter
context BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isBottomSafeArea bool
no setter
isSafeArea bool
no setter
isScaffold bool
no setter
isShowLoading bool
getter/setter pairinherited
isTopSafeArea bool
no setter
mounted bool
Whether this State object is currently in a tree.
no setterinherited
numberTabController int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget → Screen
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
closeKeyborad() → dynamic
inherited
closeLoading() → dynamic
inherited
createAppBar() PreferredSizeWidget?
createBody() Widget
createBottomBar() Widget?
inherited
createFloatingButton() Widget?
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant Screen oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
getDefaultFloatingButton({required VoidCallback onPress}) Widget
inherited
getFloatingButton({required Color color, required IconData iconData, required VoidCallback onPress}) Widget
inherited
headerView({required String title, Color backgroundColor = white, Color textColor = neutral_500, List<Widget>? actions, Widget? leading, TabBar? tabBar, double elevation = 0.5, bool isShowBack = true}) AppBar
inherited
heightBottomSafa() double
inherited
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
popToScreen({required String screen}) → void
inherited
printDebug(dynamic data) → void
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showAlertDialogAction(VoidCallback onPressYes, BuildContext context, String message, String content, String nameAction) → dynamic
inherited
showAlertDialogMessage({String? title, String content = "", double maxHeight = 150, String textCancel = "Huỷ", String textDone = "Đồng ý", VoidCallback? onDoneClick, VoidCallback? onCancelClick}) → dynamic
inherited
showDropDown({String title = "", double heightView = 300, List<OptionItem> items = const [], bool isSearch = false, CallbackData? callback, String hindText = "", Widget? childPopup, OptionItem? initItem}) → dynamic
inherited
showLoading({int timeout = 30}) → dynamic
inherited
showMessage(String content, ScaffoldState scaffoldState) → void
inherited
showPicker({CallbackData? callback, CameraType type = CameraType.full, bool isPopView = true}) → void
inherited
showPopupConfirm({String title = "", String content = "", String textButton = "", required String screen}) → dynamic
inherited
showProcessingFeatureMessage(ScaffoldState scaffoldState) → void
inherited
tabBars({List<Tab>? tabs, bool isScrollable = false, TabController? controller, EdgeInsetsGeometry labelPadding = const EdgeInsets.symmetric(horizontal: 0), EdgeInsetsGeometry indicatorPadding = const EdgeInsets.symmetric(horizontal: 0), CallbackData? callback}) TabBar
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
willPopToPreviosScreen() Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited