APIManager class

Constructors

APIManager()

Properties

countRefrest int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

check() Future<bool>
generateMd5(String data) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postWithURLEncodedNew({required String url, Map<String, dynamic>? body, Map<String, String>? headers}) Future<APIResponse>
readResponse(HttpClientResponse response) Future<String>
toString() String
A string representation of this object.
inherited
uploadFiles(String? url, Map<String, dynamic>? bodyMap, Map<String, String>? headers, Map<String, String>? mapping) Future<APIResponse>
uploadFilesMutilImage(String? url, Map<String, dynamic>? bodyMap, Map<String, String>? headers, List<MutilFiles>? mapping) Future<APIResponse>
uploadFilesOCR(String? url, Map<String, dynamic>? bodyMap, Map<String, String>? headers, Map<String, String>? mapping) Future<APIResponse>
uploadImage(String url, Map<String, String> bodyMap, Map<String, String> headers, File imageFile, String fileName) Future<APIResponse<String>>
uploadNewFile(String url, Map<String, String> bodyMap, Map<String, String> headers, Map<String, File> fileMapping) Future<Map<String, dynamic>>

Operators

operator ==(Object other) bool
The equality operator.
inherited