APIResponse<T> class

Constructors

APIResponse({T? value, String? message, String? code, int total = 0})
APIResponse.clone(T value, APIResponse one)
APIResponse.error(String? errorStr)
APIResponse.success({dynamic value})

Properties

apiCode APICode
no setter
code String?
final
fail bool
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter
total int
getter/setter pair
value ↔ T?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited