NetworkManger class

Constructors

NetworkManger()

Properties

apiManager APIManager
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post({required String url, Map<String, dynamic>? body, Map<String, String>? headers}) Future<APIResponse>
toString() String
A string representation of this object.
inherited
updateFile({required String url, Map<String, dynamic>? body, Map<String, String>? headers, Map<String, String>? mappingFile}) Future<APIResponse>
updateFileMutil({required String url, Map<String, dynamic>? body, Map<String, String>? headers, List<MutilFiles> mappingFile = const []}) Future<APIResponse>
updateFileOCR({required String url, Map<String, dynamic>? body, Map<String, String>? headers, Map<String, String>? mappingFile}) Future<APIResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited