StorageManager class

Constructors

StorageManager()

Properties

box → GetStorage
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addStorage({required String type, dynamic data}) → void
addStoragePreferences({required String type, String data = ""}) Future<void>
getStorage({required String type}) → dynamic
getStorePreferences({required String type}) Future<String?>
getStreamStorage({required String type, required CallbackData callback}) VoidCallback
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeStorage({required String type}) → dynamic
removeStoragePreferences({required String type}) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited