Control class

Implementers

Constructors

Control({required RxString title, required List listData, required String id, bool ocr = false, bool userbuy = false, required bool required, required TypeInputForm typeInput, TextInputType keyType = TextInputType.text, required RxString value, BuildContext? context, bool isSearch = true, bool? isShowDK = true, bool? isShowDKiem = true, FormatValuePresent formatShow = FormatValuePresent.Normal, required int flex, bool isShowCCCD = true, int indexRow = 0, bool notValidate = false, String icon = "", int? maxlength, required RxBool enabled, bool isShowView = true, bool isMinDateCurrent = false, String keyGetValueForShow = "MA", String keyGetValueForID = "MA", bool isDouble = false, TypeChildInputForm typeChildInput = TypeChildInputForm.datePicker, bool isLastRow = false, String keyGetListDataFormStart = '', dynamic style, bool isFirstRow = false})
Control.fromJson(String source)
factory
Control.fromMap(Map<String, dynamic> map)
factory
Control.init({required String id, required RxString value, String title = ""})
factory

Properties

context BuildContext?
getter/setter pair
enabled ↔ RxBool
getter/setter pair
flex int
getter/setter pair
formatShow FormatValuePresent
getter/setter pair
getIndexRow int
no setter
getListData → dynamic
no setter
groupValue ↔ RxString
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon String
getter/setter pair
id String
getter/setter pair
indexRow int
getter/setter pair
invalid ↔ RxString
getter/setter pair
isDouble bool
getter/setter pair
isFirstRow bool
getter/setter pair
isLastRow bool
getter/setter pair
isMinDateCurrent bool
getter/setter pair
isNotSelectDefaultValue bool
getter/setter pair
isSearch bool
getter/setter pair
isShowCCCD bool
getter/setter pair
isShowDK bool?
getter/setter pair
isShowDKiem bool?
getter/setter pair
isShowView bool
getter/setter pair
keyGetListDataFormStart String
getter/setter pair
keyGetValueForID String
getter/setter pair
keyGetValueForShow String
getter/setter pair
keyType TextInputType
getter/setter pair
listData List
getter/setter pair
maxlength int?
getter/setter pair
notValidate bool
getter/setter pair
ocr bool
getter/setter pair
required bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style ↔ dynamic
getter/setter pair
title ↔ RxString
getter/setter pair
typeChildInput TypeChildInputForm
getter/setter pair
typeInput TypeInputForm
getter/setter pair
userbuy bool
getter/setter pair
value ↔ RxString
getter/setter pair
valueSelected ↔ dynamic
getter/setter pair

Methods

clone() → dynamic
getInvalid() String
getValueSelected() → dynamic
getVisible() bool
isHideFromKenhNdCdLke() → dynamic
log() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHideFromKenhNdCdLke(bool value) → dynamic
setIndexRow(int indexRow) → void
setInvalid(dynamic invalid) → void
setListData(dynamic listData) → void
setValue(String value) → void
setValueSelected(dynamic valueSelected) → void
setVisible(bool value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited