GroupControl class

Inheritance

Constructors

GroupControl({required dynamic row})
GroupControl.fromJson(Map<String, dynamic> map)
factory
GroupControl.fromJsonPage(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
row List<List<Control>>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited