SampleCertificateModel class

Properties

detail IdCertificateDetailModel?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ids List<IdCertificateModel>
getter/setter pair
isSelect bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

jsonString() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited