OptionItem class

Constructors

OptionItem({required String id, required String title, bool isSelect = false, dynamic object, String ma = "", String image = ""})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
image String
getter/setter pair
isSelect bool
getter/setter pair
ma String
getter/setter pair
object ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited