BankObject class
Constructors
Properties
- accName ↔ String
-
getter/setter pair
- accNo ↔ String
-
getter/setter pair
- bankBranch ↔ String
-
getter/setter pair
- bankName ↔ String
-
getter/setter pair
- bankShortName ↔ String
-
getter/setter pair
- code ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String
-
getter/setter pair
- qr ↔ String
-
getter/setter pair
- qrPath ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thanhToan ↔ double?
-
getter/setter pair
Methods
-
jsonString(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromListOfResponse(
List list) → List< BankObject>