QRObject class

Constructors

QRObject({String? responseCode = '', String? responseMessage = '', String? partnerCode = '', String? orderId = '', double? collectAmountMin = 0.0, double? collectAmountMax = 0.0, String? expireDate = "", String? qrCode = "", AccountInfo? accountInfo})
QRObject.fromJson(String source)
factory
QRObject.fromMap(Map<String, dynamic> json)

Properties

accountInfo AccountInfo?
getter/setter pair
collectAmountMax double?
getter/setter pair
collectAmountMin double?
getter/setter pair
expireDate String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
orderId String?
getter/setter pair
partnerCode String?
getter/setter pair
qrCode String?
getter/setter pair
responseCode String?
getter/setter pair
responseMessage String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited