PaymentAPI class

Constructors

PaymentAPI()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hoiThanhToanTrucTiep({String? kenh, String? maDviSl, String? soIdTtoan, String? maNhaTtoan, String? playerId}) → dynamic
hoiThanhToanVA({String? kenh, String? maDviSl, String? soIdTtoan, String? maNhaTtoan, String? playerId}) → dynamic