widgets/pull_to_refresh/pull_to_refresh
library
Classes
-
bezier + circle indicator,you can use this directly
-
-
ChRefreshString
-
Chinese
-
the most common indicator,combine with a text and a icon
-
the most common indicator,combine with a text and a icon
-
a custom Indicator for footer,the usage I have put in CustomHeader,same with that
See also
-
a custom Indicator for header
-
DeRefreshString
-
German
-
EnRefreshString
-
English
-
EsRefreshString
-
Spanish
-
FrRefreshString
-
French
-
ItRefreshString
-
Italian
-
JpRefreshString
-
Japanese
-
KrRefreshString
-
Korean
-
enable footer link other footer place outside the viewport
-
enable header link other header place outside the viewport
-
LoadIndicator
-
a widget implements pull up load
-
LoadIndicatorState<T extends LoadIndicator>
-
-
LoadingProcessor
-
footer Indicator exposure interface
-
mostly use flutter inner's RefreshIndicator
-
NlRefreshString
-
Dutch
-
PtRefreshString
-
-
RefreshConfiguration
-
Controls how SmartRefresher widgets behave in a subtree.the usage just like ScrollConfiguration
-
RefreshController
-
A controller controll header and footer state,
it can trigger driving request Refresh ,set the initalRefresh,status if needed
-
RefreshIndicator
-
a widget implements ios pull down refresh effect and Android material RefreshIndicator overScroll effect
-
RefreshIndicatorState<T extends RefreshIndicator>
-
-
RefreshLocalizations
-
Implementation of localized strings for the ClassicHeader,ClassicFooter,TwoLevelHeader
-
RefreshLocalizationsDelegate
-
-
RefreshNotifier<T>
-
-
RefreshPhysics
-
-
RefreshProcessor
-
head Indicator exposure interface
-
RefreshString
-
interface implements different language
-
RuRefreshString
-
Russian
-
SmartRefresher
-
This is the most important component that provides drop-down refresh and up loading.
RefreshController must not be null,Only one controller to one SmartRefresher
-
SmartRefresherState
-
-
SvRefreshString
-
Swedish
-
this header help you implements twoLevel function easyily,
the behaviour just like TaoBao,XieCheng(携程) App TwoLevel
-
UkRefreshString
-
-
QQ ios refresh header effect
-
attach the waterdrop effect to MaterialClassicHeader