MotorController class
- Inheritance
-
- Object
- GetLifeCycle
- DisposableInterface
- GetxController
- BaseController
- BaseProductionController
- MotorController
- Implemented types
Constructors
- MotorController(dynamic dataCertificate)
Properties
- appController ↔ AppController?
-
getter/setter pairinherited
- callBackRenderView ↔ CallbackData?
-
getter/setter pairinherited
- chiTietDon ↔ dynamic
-
getter/setter pair
- context ↔ BuildContext?
-
getter/setter pairinherited
- currentPage ↔ int
-
getter/setter pairinherited
- dataCertificate ↔ dynamic
-
getter/setter pairinherited
-
formJS
↔ Map<
String, dynamic> ? -
getter/setter pair
-
formKD
↔ Map<
String, dynamic> ? -
getter/setter pairinherited
- formKdLoaded ↔ bool
-
getter/setter pairinherited
- formKenhNdCdLkeLoaded ↔ bool
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
no setterinherited
- infoProduction ↔ ProductModel?
-
getter/setter pair
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isEditFormOverView ↔ bool
-
getter/setter pairinherited
- isOverViewPage ↔ RxBool
-
getter/setter pairinherited
- isPrepareNextPage ↔ RxBool
-
getter/setter pairinherited
- isSendPushCore ↔ bool
-
getter/setter pairinherited
- isSendPushCoreSuccess ↔ RxBool
-
getter/setter pairinherited
- isShowKey ↔ RxBool
-
getter/setter pairinherited
- isShowLoading ↔ bool
-
getter/setter pairinherited
- kenhKTView ↔ String
-
getter/setter pairinherited
-
kyPhi
↔ List<
KyPhiObject> ? -
getter/setter pair
- lhNV ↔ String
-
getter/setter pairinherited
- listeners → int
-
no setterinherited
-
lsControlForOverViewPage
↔ List<
BoxOverviewPage> -
getter/setter pairinherited
-
lsPages
↔ List<
PageControl> -
getter/setter pairinherited
-
lsRow
↔ List<
Widget> -
getter/setter pairinherited
- maNV ↔ String
-
getter/setter pairinherited
- maxPageShow ↔ int?
-
getter/setter pairinherited
-
onDelete
→ InternalFinalCallback<
void> -
Internal callback that starts the cycle of this controller.
finalinherited
-
onStart
→ InternalFinalCallback<
void> -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclases.
This method should be internal and is required to define the
lifetime cycle of the subclass.
finalinherited
- pageOverview ↔ PageOverview
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- today ↔ DateTime
-
getter/setter pair
- typeFrom ↔ String
-
getter/setter pairinherited
Methods
-
$configureLifeCycle(
) → void -
inherited
-
addInputParamsDefault(
List< Control> controls) → void -
inherited
-
addListener(
GetStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, GetStateUpdate listener) → Disposer -
inherited
-
addObjectToPage(
List< Control> controls) → void -
inherited
-
callApiApproval(
CertificateObj certificate, CallbackData callback) → void -
inherited
-
callApiLayKenhNdCdLke(
String nv, String lhNv, CallbackData? callback) → Future< void> -
inherited
-
callApiNhapDon(
dynamic data, {bool isShowloading = false, bool isCloseLoading = false, CallbackData? callback}) → void -
callAPITinhPhi(
Map< String, dynamic> data) → void -
callFormKhoiDong(
) → void -
override
-
callKenhNdCdLke(
{String? lhNv}) → dynamic -
inherited
-
checkHideAndShowFromKenhNdCd(
dynamic lsKenhNdCdLke) → void -
inherited
-
checkSetVisibleNhom(
) → void -
inherited
-
closeLoading(
) → dynamic -
inherited
-
createObjectDataForRequestNhapDon(
{bool isShowloading = false, bool isCloseLoading = false, CallbackData? callback}) → void -
createObjectDataForRequestTinhPhiTNDS(
) → void -
didChangeAccessibilityFeatures(
) → void -
Called when the system changes the set of currently active accessibility
features.
inherited
-
didChangeAppLifecycleState(
AppLifecycleState state) → void -
Called when the system puts the app in the background or returns
the app to the foreground.
inherited
-
didChangeLocales(
List< Locale> ? locales) → void -
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
-
didChangeMetrics(
) → void -
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
-
didChangePlatformBrightness(
) → void -
Called when the platform brightness changes.
inherited
-
didChangeTextScaleFactor(
) → void -
Called when the platform's text scale factor changes.
inherited
-
didChangeViewFocus(
ViewFocusEvent event) → void -
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
-
didHaveMemoryPressure(
) → void -
Called when the system is running low on memory.
inherited
-
didPopRoute(
) → Future< bool> -
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
-
didPushRoute(
String route) → Future< bool> -
Called when the host tells the application to push a new route onto the
navigator.
inherited
-
didPushRouteInformation(
RouteInformation routeInformation) → Future< bool> -
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
-
didRequestAppExit(
) → Future< AppExitResponse> -
Called when a request is received from the system to exit the application.
inherited
-
disableInputWithUserNormal(
) → void -
inherited
-
dispose(
) → void -
inherited
-
disposeId(
Object id) → void -
To dispose an
idfrom future updates(), this ids are registered byGetBuilder()or similar, so is a way to unlink the state change with the Widget from the Controller.inherited -
filterWidget(
List< List< listControls, {String idRemove = ""}) → List<Control> >List< Control> > -
inherited
-
findAndUpdateControlById(
String id, {bool update = false, Control? controlNew}) → Control? -
inherited
-
findControlInputForm(
String id, {List< Widget> lsRows = const []}) → FormObject -
inherited
-
findControlInputFormAllPage(
String id) → Control -
inherited
-
getDataFromListControl(
List< List< listControls) → Map<Control> >String, dynamic> -
inherited
-
getDataInForm(
{bool isAllForm = false, List< List< ? lsRows}) → Map<Control> >String, dynamic> -
inherited
-
getFormKD(
) → void -
getFormKey(
) → GlobalKey< FormState> -
getWidgetRender(
) → List< Widget> -
inherited
-
handleCancelBackGesture(
) → void -
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
-
handleCommitBackGesture(
) → void -
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
-
handleStartBackGesture(
PredictiveBackEvent backEvent) → bool -
Called at the start of a predictive back gesture.
inherited
-
handleStatusBarTap(
) → void -
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(
PredictiveBackEvent backEvent) → void -
Called when a predictive back gesture moves.
inherited
-
initControlForOverViewPage(
) → List< BoxOverviewPage> -
override
-
initWidgetForm(
) → void -
inherited
-
jumpleOverviewPage(
) → void -
inherited
-
jumpleToIndexPage(
int index) → void -
inherited
-
lowerCaseKeyData(
List ls) → dynamic -
inherited
-
nextPage(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyChildrens(
) → void -
inherited
-
ocrCMT(
String imageUrl, String? title, {bool userbuy = false}) → Future -
override
-
ocrDangKiem(
String imageUrl, String? title, TypeOCR type) → Future -
override
-
onChangeHDKhac(
Control? obj) → void -
override
-
onChanges(
FormObject obj) → void -
override
-
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onEditingComplete(
FormObject obj) → Future< void> -
override
-
onInit(
) → Future< void> -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
parseData(
) → dynamic -
parseDataForInitForm(
dynamic data) → dynamic -
override
-
parseKenhNdCd(
dynamic field, Control control) → dynamic -
inherited
-
popToScreen(
{required String screen}) → void -
inherited
-
previousPage(
) → void -
inherited
-
printDebug(
dynamic data) → void -
inherited
-
refresh(
) → void -
inherited
-
refreshGroup(
Object id) → void -
inherited
-
refreshValueSelectedDropDownSearch(
{List< Widget> lsRows = const [], String ma = "", dynamic isForceReFresh = false}) → dynamic -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
inherited
-
renderRow(
List< List< ? ls) → List<Control> >Widget> -
inherited
-
renderView(
Control control, dynamic index, dynamic isLastRow, dynamic isFirstRow) → Widget? -
inherited
-
reRender(
) → void -
inherited
-
resetDropDownSelected(
String id, {bool isForceReFresh = false}) → dynamic -
inherited
-
setDataForDropDown(
String idWidget, List data, {List< Widget> lsRows = const []}) → void -
inherited
-
setDataForDropDownALLNew(
dynamic formKD, {String id = "", dynamic listData}) → void -
inherited
-
setDataForDropDownNew(
FormKD formKD, {List< Widget> lsRows = const []}) → void -
inherited
-
setTitleForFormByIdWidget(
String idWidget, dynamic data, {List< Widget> lsRows = const []}) → void -
inherited
-
setValueBuyControl(
String idWidget, dynamic data) → void -
inherited
-
setValueByKey(
dynamic chiTietDon, String key, {dynamic value = ""}) → void -
inherited
-
setValueByKeyAllNew(
dynamic chiTietDon, {dynamic value = "", List< Widget> lsRows = const []}) → void -
inherited
-
setValueByKeyNew(
dynamic chiTietDon, {dynamic value = "", List< Widget> lsRows = const []}) → void -
inherited
-
setValueForFormByIdWidget(
String idWidget, dynamic data, {List< Widget> lsRows = const []}) → void -
inherited
-
setValueSelectedForDropDown(
String key, {int index = 0, dynamic lsControl, bool isSetUpadteValue = false}) → void -
inherited
-
setValueSelectedForDropDownALLNew(
) → void -
inherited
-
setValueSelectedForDropDownNew(
{bool isSetUpadteValue = false, List< Widget> lsRows = const []}) → void -
inherited
-
setVisible(
List< List< listControls, bool visible) → voidControl> > -
inherited
-
setVisibleByGroupDN(
bool visible) → void -
inherited
-
setVisibleById(
String id, bool visible, {dynamic data}) → void -
inherited
-
showAlertDialogMessage(
{String? title, String content = "", double maxHeight = 150, VoidCallback? onDoneClick, VoidCallback? onCancelClick, String? titleButtonCancel, String? titleButtonDone}) → dynamic -
inherited
-
showLoading(
{int timeout = 30}) → dynamic -
inherited
-
showPicker(
{CallbackData? callback, CameraType type = CameraType.full, bool resizeImage = true}) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void -
Rebuilds
GetBuildereach time you callupdate(); Can take a List ofids, that will only update the matchingGetBuilder( id: ),idscan be reused amongGetBuilderslike group tags. The update will only notify the Widgets, ifconditionis true.inherited -
updateControlForInputForm(
Control newControl) → void -
inherited
-
updateDropwDonw(
{required DropdownSearchProduction child, bool isForceReFresh = false}) → dynamic -
inherited
-
updateMinTimeDayStart(
) → void -
upperCaseKeyData(
List ls) → dynamic -
inherited
-
validateDropDownSearch(
) → bool -
inherited
-
validateForm(
) → bool -
override
-
visibleInfoInHdKhac(
Control? obj) → void -
override
-
visibleInputOfUser(
{String product = ""}) → dynamic -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited