ConfigModel class
Constructors
- ConfigModel({bool isshowAcceptProduct = true, bool isshowCerView = true, bool isPaymentMoney = true, bool isShowCerViewList = true})
-
ConfigModel.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPaymentMoney ↔ bool
-
getter/setter pair
- isshowAcceptProduct ↔ bool
-
getter/setter pair
- isshowCerView ↔ bool
-
getter/setter pair
- isShowCerViewList ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
jsonString(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromListOfResponse(
List list) → List< ConfigModel>