DropdownSearch class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DropdownSearch
- Implemented types
Constructors
-
DropdownSearch({Key? key, String title = "", double? heightView, required List<
OptionItem> items, bool isSearch = false, CallbackData? callback, String titleDrop = "", String? hindText, Widget? childPopup, bool isRequail = false, OptionItem? initItem, String? textValidate, String hintText = "", bool enabled = true, bool isEdit = false, Control? control})
Properties
- callback ↔ CallbackData?
-
getter/setter pair
- childPopup ↔ Widget?
-
getter/setter pair
- control ↔ Control?
-
getter/setter pairoverride
- enabled ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightView ↔ double?
-
getter/setter pair
- hindText ↔ String?
-
getter/setter pair
- hintText ↔ String
-
getter/setter pair
- initItem ↔ OptionItem?
-
getter/setter pair
- isEdit ↔ bool
-
getter/setter pair
- isRequail ↔ bool
-
getter/setter pair
- isSearch ↔ bool
-
getter/setter pair
-
items
↔ List<
OptionItem> -
getter/setter pair
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textValidate ↔ String?
-
getter/setter pair
- title ↔ String
-
getter/setter pair
- titleDrop ↔ String
-
getter/setter pair
Methods
-
callReloadView(
) → void -
override
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DropdownSearch> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited